@@ -24,6 +24,7 @@ import re
 from copy import deepcopy
 import warnings
 import requests
+from requests.auth import AuthBase
 import codecs
 
 """
@@ -173,8 +174,12 @@ def openURL(url_base, data=None, method='Get', cookies=None, username=None, pass
         verify = verify and auth.verify
     else:
         auth = Authentication(username, password, cert, verify)
+
     if auth.username and auth.password:
         rkwargs['auth'] = (auth.username, auth.password)
+    elif auth.auth_delegate is not None:
+        rkwargs['auth'] = auth.auth_delegate
+
     rkwargs['cert'] = auth.cert
     rkwargs['verify'] = verify
 
@@ -379,7 +384,7 @@ def testXMLAttribute(element, attribute):
     return None
 
 
-def http_post(url=None, request=None, lang='en-US', timeout=10, username=None, password=None, auth=None):
+def http_post(url=None, request=None, lang='en-US', timeout=10, username=None, password=None, auth=None, headers=None):
     """
 
     Invoke an HTTP POST request
@@ -391,6 +396,8 @@ def http_post(url=None, request=None, lang='en-US', timeout=10, username=None, p
     - request: the request message
     - lang: the language
     - timeout: timeout in seconds
+    - auth: owslib.util.Auth instance
+    - headers: HTTP headers to send with requests
 
     """
 
@@ -399,15 +406,22 @@ def http_post(url=None, request=None, lang='en-US', timeout=10, username=None, p
 
     u = urlsplit(url)
 
-    headers = {
+    headers_ = {
         'User-Agent': 'OWSLib (https://geopython.github.io/OWSLib)',
         'Content-type': 'text/xml',
-        'Accept': 'text/xml',
+        'Accept': 'text/xml,application/xml',
         'Accept-Language': lang,
         'Accept-Encoding': 'gzip,deflate',
         'Host': u.netloc,
     }
 
+    if headers:
+        headers_.update(headers)
+
+    if isinstance(request, dict):
+        headers_['Content-type'] = 'application/json'
+        headers_.pop('Accept')
+
     rkwargs = {}
 
     if auth:
@@ -419,11 +433,15 @@ def http_post(url=None, request=None, lang='en-US', timeout=10, username=None, p
         auth = Authentication(username, password)
     if auth.username is not None and auth.password is not None:
         rkwargs['auth'] = (auth.username, auth.password)
+    elif auth.auth_delegate is not None:
+        rkwargs['auth'] = auth.auth_delegate
     rkwargs['verify'] = auth.verify
     rkwargs['cert'] = auth.cert
 
-    up = requests.post(url, request, headers=headers, **rkwargs)
-    return up.content
+    if not isinstance(request, dict):
+        return requests.post(url, request, headers=headers_, **rkwargs)
+    else:
+        return requests.post(url, json=request, headers=headers_, **rkwargs)
 
 
 def http_get(*args, **kwargs):
@@ -451,6 +469,8 @@ def http_get(*args, **kwargs):
     # Build keyword args for call to requests.get()
     if auth.username and auth.password:
         rkwargs.setdefault('auth', (auth.username, auth.password))
+    elif auth.auth_delegate is not None:
+        rkwargs['auth'] = auth.auth_delegate
     else:
         rkwargs.setdefault('auth', None)
     rkwargs.setdefault('cert', rkwargs.get('cert'))
@@ -837,11 +857,13 @@ class Authentication(object):
 
     _USERNAME = None
     _PASSWORD = None
+    _AUTH_DELEGATE = None
     _CERT = None
     _VERIFY = None
 
     def __init__(self, username=None, password=None,
-                 cert=None, verify=True, shared=False):
+                 cert=None, verify=True, shared=False,
+                 auth_delegate=None):
         '''
         :param str username=None: Username for basic authentication, None for
             unauthenticated access (or if using cert/verify)
@@ -856,12 +878,24 @@ class Authentication(object):
         :param bool shared=False: Set to True to make the values be class-level
             attributes (shared among instances where shared=True) instead of
             instance-level (shared=False, default)
+        :param AuthBase auth_delegate=None: Instance of requests' AuthBase to
+            allow arbitrary authentication schemes - mutually exclusive with
+            username/password arguments.
         '''
         self.shared = shared
+        self._username = username
+        self._password = password
+        self._cert = cert
+        self._verify = verify
+        self._auth_delegate = auth_delegate
+
+        # Trigger the setters to validate the parameters. This couldn't be done directly
+        # since some parameters are mutually exclusive.
         self.username = username
         self.password = password
         self.cert = cert
         self.verify = verify
+        self.auth_delegate = auth_delegate
 
     @property
     def username(self):
@@ -871,10 +905,15 @@ class Authentication(object):
 
     @username.setter
     def username(self, value):
-        if value is None:
-            pass
-        elif not isinstance(value, str):
-            raise TypeError('Value for "username" must be a str')
+        if value is not None:
+
+            if not isinstance(value, str):
+                raise TypeError('Value for "username" must be a str')
+
+            if self.auth_delegate is not None:
+                raise ValueError('Authentication instances may have username/password or auth_delegate set,'
+                                 ' but not both')
+
         if self.shared:
             self.__class__._USERNAME = value
         else:
@@ -888,10 +927,15 @@ class Authentication(object):
 
     @password.setter
     def password(self, value):
-        if value is None:
-            pass
-        elif not isinstance(value, str):
-            raise TypeError('Value for "password" must be a str')
+        if value is not None:
+
+            if not isinstance(value, str):
+                raise TypeError('Value for "password" must be a str')
+
+            if self.auth_delegate is not None:
+                raise ValueError('Authentication instances may have username/password or auth_delegate set,'
+                                 ' but not both')
+
         if self.shared:
             self.__class__._PASSWORD = value
         else:
@@ -951,8 +995,32 @@ class Authentication(object):
         else:
             self._verify = value
 
+    @property
+    def auth_delegate(self):
+        if self.shared:
+            return self._AUTH_DELEGATE
+        return self._auth_delegate
+
+    @auth_delegate.setter
+    def auth_delegate(self, value):
+        if value is not None:
+            if not isinstance(value, AuthBase):
+                raise TypeError('Value for "auth_delegate" must be an instance of AuthBase')
+
+            if self.username is not None or self.password is not None:
+                raise ValueError('Authentication instances may have username/password or auth_delegate set,'
+                                 ' but not both')
+
+        if self.shared:
+            self.__class__._AUTH_DELEGATE = value
+        else:
+            self._auth_delegate = value
+
     @property
     def urlopen_kwargs(self):
+        if self.auth_delegate is not None:
+            raise NotImplementedError("The urlopen_kwargs property is not supported when auth_delegate is set")
+
         return {
             'username': self.username,
             'password': self.password,
@@ -961,5 +1029,6 @@ class Authentication(object):
         }
 
     def __repr__(self, *args, **kwargs):
-        return '<{} shared={} username={} password={} cert={} verify={}>'.format(
-            self.__class__.__name__, self.shared, self.username, self.password, self.cert, self.verify)
+        return '<{} shared={} username={} password={} cert={} verify={} auth_delegate={}>'.format(
+            self.__class__.__name__, self.shared, self.username, self.password, self.cert, self.verify,
+            self.auth_delegate)
